The ballistics API reference
=============================

.. automodule:: ballistics
    :members:

The ``external`` Module
-----------------------

.. automodule:: ballistics.external
    :members:

The ``terminal`` Module
-----------------------

.. automodule:: ballistics.terminal
    :members:

The ``extras`` Module
---------------------

.. automodule:: ballistics.extras
    :members:
